pub type ERASEUICR_W<'a, const O: u8> = BitWriter<'a, u32, ERASEUICR_SPEC, ERASEUICR_A, O>;Expand description
Field ERASEUICR writer - Register starting erase of all user information configuration registers. Note that the erase must be enabled using CONFIG.WEN before the UICR can be erased.
Aliased Type
pub struct ERASEUICR_W<'a, const O: u8> { /* private fields */ }